/****************************************************************************
** Meta object code from reading C++ file 'reportinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../drkonqi-6.6.4/src/bugzillaintegration/reportinterface.h"
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'reportinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15ReportInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto ReportInterface::qt_create_metaobjectdata<qt_meta_tag_ZN15ReportInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ReportInterface",
        "awarenessChanged",
        "",
        "backtraceChanged",
        "titleChanged",
        "detailTextChanged",
        "attachToBugNumberChanged",
        "done",
        "sendReportError",
        "provideUnusualBehaviorChanged",
        "crashEventSent",
        "prepareCrashEvent",
        "prepareCrashComment",
        "createCrashMessage",
        "message",
        "sendBugReport",
        "sendSentryReport",
        "setSendWhenReady",
        "send",
        "sendUsingDefaultProduct",
        "attachBacktraceWithReport",
        "attachSent",
        "setBugAwarenessPageData",
        "ReportInterface::Reproducible",
        "selectedOptionsRating",
        "generateReportFullText",
        "ReportInterface::DrKonqiStamp",
        "stamp",
        "ReportInterface::Backtrace",
        "inlineBacktrace",
        "relatedBugzillaProducts",
        "bugzilla",
        "BugzillaManager*",
        "title",
        "detailText",
        "userRememberCrashSitutation",
        "reproducible",
        "Reproducible",
        "provideActionsApplicationDesktop",
        "provideUnusualBehavior",
        "provideApplicationConfigurationDetails",
        "backtrace",
        "isBugAwarenessPageDataUseful",
        "attachToBugNumber",
        "sentReport",
        "ReproducibleUnsure",
        "ReproducibleNever",
        "ReproducibleSometimes",
        "ReproducibleEverytime",
        "Backtrace",
        "Complete",
        "Reduced",
        "Exclude",
        "DrKonqiStamp",
        "Include"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'awarenessChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'backtraceChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'detailTextChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'attachToBugNumberChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'done'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sendReportError'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'provideUnusualBehaviorChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'crashEventSent'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'prepareCrashEvent'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'prepareCrashComment'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'createCrashMessage'
        QtMocHelpers::SlotData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'sendBugReport'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sendSentryReport'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setSendWhenReady'
        QtMocHelpers::SlotData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 18 },
        }}),
        // Slot 'sendUsingDefaultProduct'
        QtMocHelpers::SlotData<void() const>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'attachBacktraceWithReport'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'attachSent'
        QtMocHelpers::SlotData<void(int)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Method 'setBugAwarenessPageData'
        QtMocHelpers::MethodData<void(bool, ReportInterface::Reproducible, bool, bool, bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 }, { 0x80000000 | 23, 2 }, { QMetaType::Bool, 2 }, { QMetaType::Bool, 2 },
            { QMetaType::Bool, 2 },
        }}),
        // Method 'selectedOptionsRating'
        QtMocHelpers::MethodData<int() const>(24, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'generateReportFullText'
        QtMocHelpers::MethodData<QString(ReportInterface::DrKonqiStamp, ReportInterface::Backtrace) const>(25, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 26, 27 }, { 0x80000000 | 28, 29 },
        }}),
        // Method 'relatedBugzillaProducts'
        QtMocHelpers::MethodData<QStringList() const>(30, 2, QMC::AccessPublic, QMetaType::QStringList),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'bugzilla'
        QtMocHelpers::PropertyData<BugzillaManager*>(31, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'title'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'detailText'
        QtMocHelpers::PropertyData<QString>(34, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'userRememberCrashSitutation'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'reproducible'
        QtMocHelpers::PropertyData<enum Reproducible>(36, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 0),
        // property 'provideActionsApplicationDesktop'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'provideUnusualBehavior'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 7),
        // property 'provideApplicationConfigurationDetails'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'backtrace'
        QtMocHelpers::PropertyData<QString>(41, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isBugAwarenessPageDataUseful'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'attachToBugNumber'
        QtMocHelpers::PropertyData<uint>(43, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'sentReport'
        QtMocHelpers::PropertyData<uint>(44, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable, 5),
        // property 'crashEventSent'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags, 8),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Reproducible'
        QtMocHelpers::EnumData<enum Reproducible>(37, 37, QMC::EnumFlags{}).add({
            {   45, Reproducible::ReproducibleUnsure },
            {   46, Reproducible::ReproducibleNever },
            {   47, Reproducible::ReproducibleSometimes },
            {   48, Reproducible::ReproducibleEverytime },
        }),
        // enum 'Backtrace'
        QtMocHelpers::EnumData<enum Backtrace>(49, 49, QMC::EnumIsScoped).add({
            {   50, Backtrace::Complete },
            {   51, Backtrace::Reduced },
            {   52, Backtrace::Exclude },
        }),
        // enum 'DrKonqiStamp'
        QtMocHelpers::EnumData<enum DrKonqiStamp>(53, 53, QMC::EnumIsScoped).add({
            {   54, DrKonqiStamp::Include },
            {   52, DrKonqiStamp::Exclude },
        }),
    };
    return QtMocHelpers::metaObjectData<ReportInterface, qt_meta_tag_ZN15ReportInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ReportInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ReportInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ReportInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15ReportInterfaceE_t>.metaTypes,
    nullptr
} };

void ReportInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ReportInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->awarenessChanged(); break;
        case 1: _t->backtraceChanged(); break;
        case 2: _t->titleChanged(); break;
        case 3: _t->detailTextChanged(); break;
        case 4: _t->attachToBugNumberChanged(); break;
        case 5: _t->done(); break;
        case 6: _t->sendReportError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->provideUnusualBehaviorChanged(); break;
        case 8: _t->crashEventSent(); break;
        case 9: _t->prepareCrashEvent(); break;
        case 10: _t->prepareCrashComment(); break;
        case 11: _t->createCrashMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->sendBugReport(); break;
        case 13: _t->sendSentryReport(); break;
        case 14: _t->setSendWhenReady((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->sendUsingDefaultProduct(); break;
        case 16: _t->attachBacktraceWithReport(); break;
        case 17: _t->attachSent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->setBugAwarenessPageData((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ReportInterface::Reproducible>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 19: { int _r = _t->selectedOptionsRating();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 20: { QString _r = _t->generateReportFullText((*reinterpret_cast<std::add_pointer_t<ReportInterface::DrKonqiStamp>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ReportInterface::Backtrace>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 21: { QStringList _r = _t->relatedBugzillaProducts();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ReportInterface::*)()>(_a, &ReportInterface::awarenessChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReportInterface::*)()>(_a, &ReportInterface::backtraceChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReportInterface::*)()>(_a, &ReportInterface::titleChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReportInterface::*)()>(_a, &ReportInterface::detailTextChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReportInterface::*)()>(_a, &ReportInterface::attachToBugNumberChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReportInterface::*)()>(_a, &ReportInterface::done, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReportInterface::*)(const QString & )>(_a, &ReportInterface::sendReportError, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReportInterface::*)()>(_a, &ReportInterface::provideUnusualBehaviorChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReportInterface::*)()>(_a, &ReportInterface::crashEventSent, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<BugzillaManager**>(_v) = _t->bugzillaManager(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->m_reportDetailText; break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->m_userRememberCrashSituation; break;
        case 4: *reinterpret_cast<enum Reproducible*>(_v) = _t->m_reproducible; break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->m_provideActionsApplicationDesktop; break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->m_provideUnusualBehavior; break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->m_provideApplicationConfigurationDetails; break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->backtrace(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isBugAwarenessPageDataUseful(); break;
        case 10: *reinterpret_cast<uint*>(_v) = _t->attachToBugNumber(); break;
        case 11: *reinterpret_cast<uint*>(_v) = _t->m_sentReport; break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->hasCrashEventSent(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setTitle(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setDetailText(*reinterpret_cast<QString*>(_v)); break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_userRememberCrashSituation, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->awarenessChanged();
            break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_reproducible, *reinterpret_cast<enum Reproducible*>(_v)))
                Q_EMIT _t->awarenessChanged();
            break;
        case 5:
            if (QtMocHelpers::setProperty(_t->m_provideActionsApplicationDesktop, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->awarenessChanged();
            break;
        case 6:
            if (QtMocHelpers::setProperty(_t->m_provideUnusualBehavior, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->provideUnusualBehaviorChanged();
            break;
        case 7:
            if (QtMocHelpers::setProperty(_t->m_provideApplicationConfigurationDetails, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->awarenessChanged();
            break;
        case 8: _t->setBacktrace(*reinterpret_cast<QString*>(_v)); break;
        case 10: _t->setAttachToBugNumber(*reinterpret_cast<uint*>(_v)); break;
        case 11:
            if (QtMocHelpers::setProperty(_t->m_sentReport, *reinterpret_cast<uint*>(_v)))
                Q_EMIT _t->done();
            break;
        default: break;
        }
    }
}

const QMetaObject *ReportInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ReportInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ReportInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ReportInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 22;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void ReportInterface::awarenessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ReportInterface::backtraceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ReportInterface::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ReportInterface::detailTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ReportInterface::attachToBugNumberChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ReportInterface::done()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ReportInterface::sendReportError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void ReportInterface::provideUnusualBehaviorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void ReportInterface::crashEventSent()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
