/****************************************************************************
** Meta object code from reading C++ file 'debugpackageinstaller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../drkonqi-6.6.4/src/debugpackageinstaller.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'debugpackageinstaller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21DebugPackageInstallerE_t {};
} // unnamed namespace

template <> constexpr inline auto DebugPackageInstaller::qt_create_metaobjectdata<qt_meta_tag_ZN21DebugPackageInstallerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DebugPackageInstaller",
        "packagesInstalled",
        "",
        "error",
        "canceled",
        "processFinished",
        "QProcess::ExitStatus",
        "progressDialogCanceled",
        "setMissingLibraries",
        "installDebugPackages",
        "canInstallDebugPackages",
        "Results",
        "ResultInstalled",
        "ResultError",
        "ResultSymbolsNotFound",
        "ResultCanceled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'packagesInstalled'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'canceled'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'processFinished'
        QtMocHelpers::SlotData<void(int, QProcess::ExitStatus)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { 0x80000000 | 6, 2 },
        }}),
        // Slot 'progressDialogCanceled'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'setMissingLibraries'
        QtMocHelpers::MethodData<void(const QStringList &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 2 },
        }}),
        // Method 'installDebugPackages'
        QtMocHelpers::MethodData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'canInstallDebugPackages'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Results'
        QtMocHelpers::EnumData<enum Results>(11, 11, QMC::EnumFlags{}).add({
            {   12, Results::ResultInstalled },
            {   13, Results::ResultError },
            {   14, Results::ResultSymbolsNotFound },
            {   15, Results::ResultCanceled },
        }),
    };
    return QtMocHelpers::metaObjectData<DebugPackageInstaller, qt_meta_tag_ZN21DebugPackageInstallerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DebugPackageInstaller::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21DebugPackageInstallerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21DebugPackageInstallerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21DebugPackageInstallerE_t>.metaTypes,
    nullptr
} };

void DebugPackageInstaller::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DebugPackageInstaller *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->packagesInstalled(); break;
        case 1: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->canceled(); break;
        case 3: _t->processFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QProcess::ExitStatus>>(_a[2]))); break;
        case 4: _t->progressDialogCanceled(); break;
        case 5: _t->setMissingLibraries((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 6: _t->installDebugPackages(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DebugPackageInstaller::*)()>(_a, &DebugPackageInstaller::packagesInstalled, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DebugPackageInstaller::*)(const QString & )>(_a, &DebugPackageInstaller::error, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DebugPackageInstaller::*)()>(_a, &DebugPackageInstaller::canceled, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->canInstallDebugPackages(); break;
        default: break;
        }
    }
}

const QMetaObject *DebugPackageInstaller::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DebugPackageInstaller::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21DebugPackageInstallerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DebugPackageInstaller::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void DebugPackageInstaller::packagesInstalled()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DebugPackageInstaller::error(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DebugPackageInstaller::canceled()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
