// This file is generated by kconfig_compiler_kf6 from settings.kcfg.
// All changes you do to this file will be lost.
#ifndef SETTINGS_H
#define SETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class Settings : public KConfigSkeleton
{
  Q_OBJECT
  public:

    static Settings *self();
    ~Settings() override;

    /**
      Set Sentry
    */
    static
    void setSentry( bool v )
    {
      if (v != self()->mSentry && !self()->isSentryImmutable()) {
        self()->mSentry = v;
        Q_EMIT self()->SentryChanged();
      }
    }

    Q_PROPERTY(bool sentry READ sentry WRITE setSentry NOTIFY SentryChanged)
    Q_PROPERTY(bool isSentryImmutable READ isSentryImmutable CONSTANT)
    Q_PROPERTY(bool defaultSentryValue READ defaultSentryValue CONSTANT)
    /**
      Get Sentry
    */
    static
    bool sentry()
    {
      return self()->mSentry;
    }

    /**
      Is Sentry Immutable
    */
    static
    bool isSentryImmutable()
    {
      return self()->isImmutable( QStringLiteral( "Sentry" ) );
    }

    /**
      Get Sentry default value
    */
    static
    bool defaultSentryValue()
    {
        return defaultSentryValue_helper();
    }

    /**
      Set DownloadSymbols
    */
    static
    void setDownloadSymbols( bool v )
    {
      if (v != self()->mDownloadSymbols && !self()->isDownloadSymbolsImmutable()) {
        self()->mDownloadSymbols = v;
        Q_EMIT self()->DownloadSymbolsChanged();
      }
    }

    Q_PROPERTY(bool downloadSymbols READ downloadSymbols WRITE setDownloadSymbols NOTIFY DownloadSymbolsChanged)
    Q_PROPERTY(bool isDownloadSymbolsImmutable READ isDownloadSymbolsImmutable CONSTANT)
    Q_PROPERTY(bool defaultDownloadSymbolsValue READ defaultDownloadSymbolsValue CONSTANT)
    /**
      Get DownloadSymbols
    */
    static
    bool downloadSymbols()
    {
      return self()->mDownloadSymbols;
    }

    /**
      Is DownloadSymbols Immutable
    */
    static
    bool isDownloadSymbolsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "DownloadSymbols" ) );
    }

    /**
      Get DownloadSymbols default value
    */
    static
    bool defaultDownloadSymbolsValue()
    {
        return defaultDownloadSymbolsValue_helper();
    }


    enum {
      signalSentryChanged = 1,
      signalDownloadSymbolsChanged = 2
    };

  Q_SIGNALS:
    void SentryChanged();

    void DownloadSymbolsChanged();

  private:
    void itemChanged(quint64 signalFlag);

  protected:
    Settings();
    friend class SettingsHelper;


    // DrKonqi
    bool mSentry;
    static bool defaultSentryValue_helper();
    bool mDownloadSymbols;
    static bool defaultDownloadSymbolsValue_helper();
};

#endif

