/****************************************************************************
** Meta object code from reading C++ file 'bugzillalib.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../drkonqi-6.6.4/src/bugzillaintegration/bugzillalib.h"
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bugzillalib.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15BugzillaManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto BugzillaManager::qt_create_metaobjectdata<qt_meta_tag_ZN15BugzillaManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BugzillaManager",
        "loginFinished",
        "",
        "logged",
        "reportSent",
        "bugId",
        "attachToReportSent",
        "productInfoFetched",
        "Bugzilla::Product::Ptr",
        "product",
        "bugzillaVersionFound",
        "loginError",
        "errorMsg",
        "bugReportError",
        "jobOwner",
        "sendReportError",
        "sendReportErrorInvalidValues",
        "attachToReportError",
        "productInfoError",
        "bugzillaVersionError",
        "tryLogin",
        "username",
        "password",
        "refreshToken",
        "lookupVersion"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'loginFinished'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'reportSent'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'attachToReportSent'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'productInfoFetched'
        QtMocHelpers::SignalData<void(const Bugzilla::Product::Ptr &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'bugzillaVersionFound'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loginError'
        QtMocHelpers::SignalData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Signal 'bugReportError'
        QtMocHelpers::SignalData<void(const QString &, QObject *)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::QObjectStar, 14 },
        }}),
        // Signal 'sendReportError'
        QtMocHelpers::SignalData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Signal 'sendReportErrorInvalidValues'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'attachToReportError'
        QtMocHelpers::SignalData<void(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Signal 'productInfoError'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bugzillaVersionError'
        QtMocHelpers::SignalData<void(const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Method 'tryLogin'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(20, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 21 }, { QMetaType::QString, 22 },
        }}),
        // Method 'refreshToken'
        QtMocHelpers::MethodData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'lookupVersion'
        QtMocHelpers::MethodData<void()>(24, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BugzillaManager, qt_meta_tag_ZN15BugzillaManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BugzillaManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15BugzillaManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15BugzillaManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15BugzillaManagerE_t>.metaTypes,
    nullptr
} };

void BugzillaManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BugzillaManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->loginFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->reportSent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->attachToReportSent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->productInfoFetched((*reinterpret_cast<std::add_pointer_t<Bugzilla::Product::Ptr>>(_a[1]))); break;
        case 4: _t->bugzillaVersionFound(); break;
        case 5: _t->loginError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->bugReportError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[2]))); break;
        case 7: _t->sendReportError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->sendReportErrorInvalidValues(); break;
        case 9: _t->attachToReportError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->productInfoError(); break;
        case 11: _t->bugzillaVersionError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->tryLogin((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 13: _t->refreshToken(); break;
        case 14: _t->lookupVersion(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BugzillaManager::*)(bool )>(_a, &BugzillaManager::loginFinished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BugzillaManager::*)(int )>(_a, &BugzillaManager::reportSent, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BugzillaManager::*)(int )>(_a, &BugzillaManager::attachToReportSent, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (BugzillaManager::*)(const Bugzilla::Product::Ptr & )>(_a, &BugzillaManager::productInfoFetched, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (BugzillaManager::*)()>(_a, &BugzillaManager::bugzillaVersionFound, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (BugzillaManager::*)(const QString & )>(_a, &BugzillaManager::loginError, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (BugzillaManager::*)(const QString & , QObject * )>(_a, &BugzillaManager::bugReportError, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (BugzillaManager::*)(const QString & )>(_a, &BugzillaManager::sendReportError, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (BugzillaManager::*)()>(_a, &BugzillaManager::sendReportErrorInvalidValues, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (BugzillaManager::*)(const QString & )>(_a, &BugzillaManager::attachToReportError, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (BugzillaManager::*)()>(_a, &BugzillaManager::productInfoError, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (BugzillaManager::*)(const QString & )>(_a, &BugzillaManager::bugzillaVersionError, 11))
            return;
    }
}

const QMetaObject *BugzillaManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BugzillaManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15BugzillaManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int BugzillaManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void BugzillaManager::loginFinished(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void BugzillaManager::reportSent(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void BugzillaManager::attachToReportSent(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void BugzillaManager::productInfoFetched(const Bugzilla::Product::Ptr & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void BugzillaManager::bugzillaVersionFound()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void BugzillaManager::loginError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void BugzillaManager::bugReportError(const QString & _t1, QObject * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void BugzillaManager::sendReportError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void BugzillaManager::sendReportErrorInvalidValues()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void BugzillaManager::attachToReportError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void BugzillaManager::productInfoError()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void BugzillaManager::bugzillaVersionError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}
QT_WARNING_POP
