/****************************************************************************
** Meta object code from reading C++ file 'newbug.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../drkonqi-6.6.4/src/bugzillaintegration/libbugzilla/clients/commands/newbug.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'newbug.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8Bugzilla6NewBugE_t {};
} // unnamed namespace

template <> constexpr inline auto Bugzilla::NewBug::qt_create_metaobjectdata<qt_meta_tag_ZN8Bugzilla6NewBugE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Bugzilla::NewBug",
        "product",
        "component",
        "summary",
        "version",
        "description",
        "op_sys",
        "platform",
        "priority",
        "severity",
        "keywords"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'product'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'component'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'summary'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'version'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'description'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'op_sys'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'platform'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'priority'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'severity'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'keywords'
        QtMocHelpers::PropertyData<QStringList>(10, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NewBug, qt_meta_tag_ZN8Bugzilla6NewBugE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Bugzilla::NewBug::staticMetaObject = { {
    QMetaObject::SuperData::link<JsonCommand::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Bugzilla6NewBugE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Bugzilla6NewBugE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8Bugzilla6NewBugE_t>.metaTypes,
    nullptr
} };

void Bugzilla::NewBug::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NewBug *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->product; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->component; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->summary; break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->version; break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->description; break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->op_sys; break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->platform; break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->priority; break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->severity; break;
        case 9: *reinterpret_cast<QStringList*>(_v) = _t->keywords; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->product, *reinterpret_cast<QString*>(_v)); break;
        case 1: QtMocHelpers::setProperty(_t->component, *reinterpret_cast<QString*>(_v)); break;
        case 2: QtMocHelpers::setProperty(_t->summary, *reinterpret_cast<QString*>(_v)); break;
        case 3: QtMocHelpers::setProperty(_t->version, *reinterpret_cast<QString*>(_v)); break;
        case 4: QtMocHelpers::setProperty(_t->description, *reinterpret_cast<QString*>(_v)); break;
        case 5: QtMocHelpers::setProperty(_t->op_sys, *reinterpret_cast<QString*>(_v)); break;
        case 6: QtMocHelpers::setProperty(_t->platform, *reinterpret_cast<QString*>(_v)); break;
        case 7: QtMocHelpers::setProperty(_t->priority, *reinterpret_cast<QString*>(_v)); break;
        case 8: QtMocHelpers::setProperty(_t->severity, *reinterpret_cast<QString*>(_v)); break;
        case 9: QtMocHelpers::setProperty(_t->keywords, *reinterpret_cast<QStringList*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Bugzilla::NewBug::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Bugzilla::NewBug::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Bugzilla6NewBugE_t>.strings))
        return static_cast<void*>(this);
    return JsonCommand::qt_metacast(_clname);
}

int Bugzilla::NewBug::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = JsonCommand::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}
QT_WARNING_POP
