/****************************************************************************
** Meta object code from reading C++ file 'backtracegenerator.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../drkonqi-6.6.4/src/backtracegenerator.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'backtracegenerator.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18BacktraceGeneratorE_t {};
} // unnamed namespace

template <> constexpr inline auto BacktraceGenerator::qt_create_metaobjectdata<qt_meta_tag_ZN18BacktraceGeneratorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BacktraceGenerator",
        "starting",
        "",
        "newLine",
        "str",
        "someError",
        "failedToStart",
        "done",
        "preparing",
        "stateChanged",
        "symbolResolutionChanged",
        "crampedMemoryChanged",
        "start",
        "hasAnyFailure",
        "slotProcessExited",
        "exitCode",
        "QProcess::ExitStatus",
        "exitStatus",
        "slotReadInput",
        "slotOnErrorOccurred",
        "QProcess::ProcessError",
        "error",
        "parser",
        "BacktraceParser*",
        "backtrace",
        "debuggerIsGDB",
        "debuggerName",
        "rawTraceUrlAndDoNotAutoRemove",
        "QUrl",
        "rawTraceData",
        "state",
        "State",
        "supportsSymbolResolution",
        "symbolResolution",
        "hasRawTraceData",
        "crampedMemory",
        "NotLoaded",
        "Loading",
        "Loaded",
        "Failed",
        "FailedToStart",
        "MemoryPressure"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'starting'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newLine'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'someError'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'failedToStart'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'done'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'preparing'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'symbolResolutionChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'crampedMemoryChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'start'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'hasAnyFailure'
        QtMocHelpers::SlotData<bool()>(13, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'slotProcessExited'
        QtMocHelpers::SlotData<void(int, QProcess::ExitStatus)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { 0x80000000 | 16, 17 },
        }}),
        // Slot 'slotReadInput'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotOnErrorOccurred'
        QtMocHelpers::SlotData<void(QProcess::ProcessError)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Method 'parser'
        QtMocHelpers::MethodData<BacktraceParser *() const>(22, 2, QMC::AccessPublic, 0x80000000 | 23),
        // Method 'backtrace'
        QtMocHelpers::MethodData<QString() const>(24, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'debuggerIsGDB'
        QtMocHelpers::MethodData<bool() const>(25, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'debuggerName'
        QtMocHelpers::MethodData<QString() const>(26, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'rawTraceUrlAndDoNotAutoRemove'
        QtMocHelpers::MethodData<QUrl()>(27, 2, QMC::AccessPublic, 0x80000000 | 28),
        // Method 'rawTraceData'
        QtMocHelpers::MethodData<QString()>(29, 2, QMC::AccessPublic, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'state'
        QtMocHelpers::PropertyData<enum State>(30, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 6),
        // property 'hasAnyFailure'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'supportsSymbolResolution'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'symbolResolution'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 7),
        // property 'hasRawTraceData'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'crampedMemory'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 8),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'State'
        QtMocHelpers::EnumData<enum State>(31, 31, QMC::EnumFlags{}).add({
            {   36, State::NotLoaded },
            {   37, State::Loading },
            {   38, State::Loaded },
            {   39, State::Failed },
            {   40, State::FailedToStart },
            {   41, State::MemoryPressure },
        }),
    };
    return QtMocHelpers::metaObjectData<BacktraceGenerator, qt_meta_tag_ZN18BacktraceGeneratorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BacktraceGenerator::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18BacktraceGeneratorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18BacktraceGeneratorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18BacktraceGeneratorE_t>.metaTypes,
    nullptr
} };

void BacktraceGenerator::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BacktraceGenerator *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->starting(); break;
        case 1: _t->newLine((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->someError(); break;
        case 3: _t->failedToStart(); break;
        case 4: _t->done(); break;
        case 5: _t->preparing(); break;
        case 6: _t->stateChanged(); break;
        case 7: _t->symbolResolutionChanged(); break;
        case 8: _t->crampedMemoryChanged(); break;
        case 9: _t->start(); break;
        case 10: { bool _r = _t->hasAnyFailure();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->slotProcessExited((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QProcess::ExitStatus>>(_a[2]))); break;
        case 12: _t->slotReadInput(); break;
        case 13: _t->slotOnErrorOccurred((*reinterpret_cast<std::add_pointer_t<QProcess::ProcessError>>(_a[1]))); break;
        case 14: { BacktraceParser* _r = _t->parser();
            if (_a[0]) *reinterpret_cast<BacktraceParser**>(_a[0]) = std::move(_r); }  break;
        case 15: { QString _r = _t->backtrace();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->debuggerIsGDB();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { QString _r = _t->debuggerName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 18: { QUrl _r = _t->rawTraceUrlAndDoNotAutoRemove();
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 19: { QString _r = _t->rawTraceData();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BacktraceGenerator::*)()>(_a, &BacktraceGenerator::starting, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BacktraceGenerator::*)(const QString & )>(_a, &BacktraceGenerator::newLine, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BacktraceGenerator::*)()>(_a, &BacktraceGenerator::someError, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (BacktraceGenerator::*)()>(_a, &BacktraceGenerator::failedToStart, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (BacktraceGenerator::*)()>(_a, &BacktraceGenerator::done, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (BacktraceGenerator::*)()>(_a, &BacktraceGenerator::preparing, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (BacktraceGenerator::*)()>(_a, &BacktraceGenerator::stateChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (BacktraceGenerator::*)()>(_a, &BacktraceGenerator::symbolResolutionChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (BacktraceGenerator::*)()>(_a, &BacktraceGenerator::crampedMemoryChanged, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum State*>(_v) = _t->state(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->hasAnyFailure(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->m_supportsSymbolResolution; break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->m_symbolResolution; break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->hasRawTraceData(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->m_crampedMemory; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 3:
            if (QtMocHelpers::setProperty(_t->m_symbolResolution, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->symbolResolutionChanged();
            break;
        case 5:
            if (QtMocHelpers::setProperty(_t->m_crampedMemory, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->crampedMemoryChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *BacktraceGenerator::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BacktraceGenerator::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18BacktraceGeneratorE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int BacktraceGenerator::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void BacktraceGenerator::starting()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void BacktraceGenerator::newLine(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void BacktraceGenerator::someError()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void BacktraceGenerator::failedToStart()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void BacktraceGenerator::done()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void BacktraceGenerator::preparing()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void BacktraceGenerator::stateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void BacktraceGenerator::symbolResolutionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void BacktraceGenerator::crampedMemoryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
