/********************************************************************************
** Form generated from reading UI file 'backtracewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BACKTRACEWIDGET_H
#define UI_BACKTRACEWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "statuswidget.h"

QT_BEGIN_NAMESPACE

class Ui_Form
{
public:
    QVBoxLayout *verticalLayout_4;
    QVBoxLayout *verticalLayout;
    StatusWidget *m_statusWidget;
    QVBoxLayout *mainLayout;
    QStackedWidget *m_backtraceStack;
    QWidget *backtracePage;
    QHBoxLayout *horizontalLayout;
    QTextBrowser *m_backtraceEdit;
    QWidget *backtraceHelpPage;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_3;
    QLabel *m_backtraceHelpIcon;
    QLabel *m_backtraceHelpLabel;
    QSpacerItem *verticalSpacer;
    QCheckBox *m_toggleBacktraceCheckBox;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *m_reloadBacktraceButton;
    QPushButton *m_installDebugButton;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *m_copyButton;
    QPushButton *m_saveButton;
    QVBoxLayout *verticalLayout_2;
    QLabel *m_extraDetailsLabel;

    void setupUi(QWidget *Form)
    {
        if (Form->objectName().isEmpty())
            Form->setObjectName("Form");
        Form->resize(511, 476);
        Form->setWindowTitle(QString::fromUtf8("GetBacktraceWidget"));
        verticalLayout_4 = new QVBoxLayout(Form);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        m_statusWidget = new StatusWidget(Form);
        m_statusWidget->setObjectName("m_statusWidget");

        verticalLayout->addWidget(m_statusWidget);

        mainLayout = new QVBoxLayout();
        mainLayout->setObjectName("mainLayout");
        m_backtraceStack = new QStackedWidget(Form);
        m_backtraceStack->setObjectName("m_backtraceStack");
        backtracePage = new QWidget();
        backtracePage->setObjectName("backtracePage");
        horizontalLayout = new QHBoxLayout(backtracePage);
        horizontalLayout->setSpacing(0);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        m_backtraceEdit = new QTextBrowser(backtracePage);
        m_backtraceEdit->setObjectName("m_backtraceEdit");

        horizontalLayout->addWidget(m_backtraceEdit);

        m_backtraceStack->addWidget(backtracePage);
        backtraceHelpPage = new QWidget();
        backtraceHelpPage->setObjectName("backtraceHelpPage");
        verticalLayout_3 = new QVBoxLayout(backtraceHelpPage);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(4, 4, 4, 4);
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(10);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        m_backtraceHelpIcon = new QLabel(backtraceHelpPage);
        m_backtraceHelpIcon->setObjectName("m_backtraceHelpIcon");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_backtraceHelpIcon->sizePolicy().hasHeightForWidth());
        m_backtraceHelpIcon->setSizePolicy(sizePolicy);
        m_backtraceHelpIcon->setMaximumSize(QSize(48, 48));
        m_backtraceHelpIcon->setScaledContents(true);

        horizontalLayout_3->addWidget(m_backtraceHelpIcon);

        m_backtraceHelpLabel = new QLabel(backtraceHelpPage);
        m_backtraceHelpLabel->setObjectName("m_backtraceHelpLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_backtraceHelpLabel->sizePolicy().hasHeightForWidth());
        m_backtraceHelpLabel->setSizePolicy(sizePolicy1);
        m_backtraceHelpLabel->setWordWrap(true);

        horizontalLayout_3->addWidget(m_backtraceHelpLabel);


        verticalLayout_3->addLayout(horizontalLayout_3);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);

        m_backtraceStack->addWidget(backtraceHelpPage);

        mainLayout->addWidget(m_backtraceStack);

        m_toggleBacktraceCheckBox = new QCheckBox(Form);
        m_toggleBacktraceCheckBox->setObjectName("m_toggleBacktraceCheckBox");

        mainLayout->addWidget(m_toggleBacktraceCheckBox);


        verticalLayout->addLayout(mainLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        m_reloadBacktraceButton = new QPushButton(Form);
        m_reloadBacktraceButton->setObjectName("m_reloadBacktraceButton");
        m_reloadBacktraceButton->setProperty("isDragEnabled", QVariant(false));

        horizontalLayout_2->addWidget(m_reloadBacktraceButton);

        m_installDebugButton = new QPushButton(Form);
        m_installDebugButton->setObjectName("m_installDebugButton");

        horizontalLayout_2->addWidget(m_installDebugButton);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        m_copyButton = new QPushButton(Form);
        m_copyButton->setObjectName("m_copyButton");

        horizontalLayout_2->addWidget(m_copyButton);

        m_saveButton = new QPushButton(Form);
        m_saveButton->setObjectName("m_saveButton");

        horizontalLayout_2->addWidget(m_saveButton);


        verticalLayout->addLayout(horizontalLayout_2);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        m_extraDetailsLabel = new QLabel(Form);
        m_extraDetailsLabel->setObjectName("m_extraDetailsLabel");
        sizePolicy1.setHeightForWidth(m_extraDetailsLabel->sizePolicy().hasHeightForWidth());
        m_extraDetailsLabel->setSizePolicy(sizePolicy1);
        m_extraDetailsLabel->setTextFormat(Qt::RichText);
        m_extraDetailsLabel->setWordWrap(true);
        m_extraDetailsLabel->setOpenExternalLinks(false);

        verticalLayout_2->addWidget(m_extraDetailsLabel);


        verticalLayout->addLayout(verticalLayout_2);


        verticalLayout_4->addLayout(verticalLayout);


        retranslateUi(Form);

        m_backtraceStack->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(Form);
    } // setupUi

    void retranslateUi(QWidget *Form)
    {
        m_toggleBacktraceCheckBox->setText(tr2i18n("Show backtrace content (advanced)", nullptr));
        (void)Form;
    } // retranslateUi

};

namespace Ui {
    class Form: public Ui_Form {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BACKTRACEWIDGET_H

