/****************************************************************************
** Meta object code from reading C++ file 'bug.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../drkonqi-6.6.4/src/bugzillaintegration/libbugzilla/models/bug.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bug.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8Bugzilla3BugE_t {};
} // unnamed namespace

template <> constexpr inline auto Bugzilla::Bug::qt_create_metaobjectdata<qt_meta_tag_ZN8Bugzilla3BugE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Bugzilla::Bug",
        "commentsChanged",
        "",
        "changed",
        "id",
        "product",
        "component",
        "summary",
        "version",
        "is_open",
        "op_sys",
        "priority",
        "severity",
        "status",
        "Status",
        "resolution",
        "Resolution",
        "dupe_of",
        "Unknown",
        "UNCONFIRMED",
        "CONFIRMED",
        "ASSIGNED",
        "REOPENED",
        "RESOLVED",
        "NEEDSINFO",
        "VERIFIED",
        "CLOSED",
        "NONE",
        "FIXED",
        "INVALID",
        "WONTFIX",
        "LATER",
        "REMIND",
        "DUPLICATE",
        "WORKSFORME",
        "MOVED",
        "UPSTREAM",
        "DOWNSTREAM",
        "WAITINGFORINFO",
        "BACKTRACE",
        "UNMAINTAINED"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'commentsChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'id'
        QtMocHelpers::PropertyData<qint64>(4, QMetaType::LongLong, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'product'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'component'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'summary'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'version'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'is_open'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'op_sys'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'priority'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'severity'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'status'
        QtMocHelpers::PropertyData<enum Status>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 1),
        // property 'resolution'
        QtMocHelpers::PropertyData<enum Resolution>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 1),
        // property 'dupe_of'
        QtMocHelpers::PropertyData<qint64>(17, QMetaType::LongLong, QMC::DefaultPropertyFlags | QMC::Writable, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Status'
        QtMocHelpers::EnumData<enum Status>(14, 14, QMC::EnumIsScoped).add({
            {   18, Status::Unknown },
            {   19, Status::UNCONFIRMED },
            {   20, Status::CONFIRMED },
            {   21, Status::ASSIGNED },
            {   22, Status::REOPENED },
            {   23, Status::RESOLVED },
            {   24, Status::NEEDSINFO },
            {   25, Status::VERIFIED },
            {   26, Status::CLOSED },
        }),
        // enum 'Resolution'
        QtMocHelpers::EnumData<enum Resolution>(16, 16, QMC::EnumIsScoped).add({
            {   18, Resolution::Unknown },
            {   27, Resolution::NONE },
            {   28, Resolution::FIXED },
            {   29, Resolution::INVALID },
            {   30, Resolution::WONTFIX },
            {   31, Resolution::LATER },
            {   32, Resolution::REMIND },
            {   33, Resolution::DUPLICATE },
            {   34, Resolution::WORKSFORME },
            {   35, Resolution::MOVED },
            {   36, Resolution::UPSTREAM },
            {   37, Resolution::DOWNSTREAM },
            {   38, Resolution::WAITINGFORINFO },
            {   39, Resolution::BACKTRACE },
            {   40, Resolution::UNMAINTAINED },
        }),
    };
    return QtMocHelpers::metaObjectData<Bug, qt_meta_tag_ZN8Bugzilla3BugE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Bugzilla::Bug::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Bugzilla3BugE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Bugzilla3BugE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8Bugzilla3BugE_t>.metaTypes,
    nullptr
} };

void Bugzilla::Bug::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Bug *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->commentsChanged(); break;
        case 1: _t->changed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Bug::*)()>(_a, &Bug::commentsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bug::*)()>(_a, &Bug::changed, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qint64*>(_v) = _t->id(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->product(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->component(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->summary(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->version(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->is_open(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->op_sys(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->priority(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->severity(); break;
        case 9: *reinterpret_cast<enum Status*>(_v) = _t->status(); break;
        case 10: *reinterpret_cast<enum Resolution*>(_v) = _t->resolution(); break;
        case 11: *reinterpret_cast<qint64*>(_v) = _t->dupe_of(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->m_id, *reinterpret_cast<qint64*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_product, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_component, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_summary, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_version, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 5:
            if (QtMocHelpers::setProperty(_t->m_is_open, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 6:
            if (QtMocHelpers::setProperty(_t->m_op_sys, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 7:
            if (QtMocHelpers::setProperty(_t->m_priority, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 8:
            if (QtMocHelpers::setProperty(_t->m_severity, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 9:
            if (QtMocHelpers::setProperty(_t->m_status, *reinterpret_cast<enum Status*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 10:
            if (QtMocHelpers::setProperty(_t->m_resolution, *reinterpret_cast<enum Resolution*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 11:
            if (QtMocHelpers::setProperty(_t->m_dupe_of, *reinterpret_cast<qint64*>(_v)))
                Q_EMIT _t->changed();
            break;
        default: break;
        }
    }
}

const QMetaObject *Bugzilla::Bug::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Bugzilla::Bug::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Bugzilla3BugE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Bugzilla::Bug::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void Bugzilla::Bug::commentsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Bugzilla::Bug::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
