/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.systemd1.Unit.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef UNITINTERFACE_H
#define UNITINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>
#include "dbustypes.h"

/*
 * Proxy class for interface org.freedesktop.systemd1.Unit
 */
class OrgFreedesktopSystemd1UnitInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.systemd1.Unit"; }

public:
    OrgFreedesktopSystemd1UnitInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgFreedesktopSystemd1UnitInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> SetProperties(bool runtime, const QVariantMultiMap &properties)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(runtime) << QVariant::fromValue(properties);
        return asyncCallWithArgumentList(QStringLiteral("SetProperties"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace freedesktop {
    namespace systemd1 {
      using Unit = ::OrgFreedesktopSystemd1UnitInterface;
    }
  }
}

#endif
