/********************************************************************************
** Form generated from reading UI file 'maindialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAINDIALOG_H
#define UI_MAINDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_MainWidget
{
public:
    QVBoxLayout *verticalLayout_3;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout_2;
    QVBoxLayout *verticalLayout;
    QLabel *titleLabel;
    QLabel *infoLabel;
    QSpacerItem *verticalSpacer_3;
    QLabel *detailsTitleLabel;
    QLabel *detailsLabel;

    void setupUi(QWidget *MainWidget)
    {
        if (MainWidget->objectName().isEmpty())
            MainWidget->setObjectName("MainWidget");
        MainWidget->resize(404, 289);
        verticalLayout_3 = new QVBoxLayout(MainWidget);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_3->addItem(verticalSpacer);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        titleLabel = new QLabel(MainWidget);
        titleLabel->setObjectName("titleLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(titleLabel->sizePolicy().hasHeightForWidth());
        titleLabel->setSizePolicy(sizePolicy);
        titleLabel->setText(QString::fromUtf8(""));
        titleLabel->setWordWrap(true);

        verticalLayout->addWidget(titleLabel);

        infoLabel = new QLabel(MainWidget);
        infoLabel->setObjectName("infoLabel");
        sizePolicy.setHeightForWidth(infoLabel->sizePolicy().hasHeightForWidth());
        infoLabel->setSizePolicy(sizePolicy);
        infoLabel->setText(QString::fromUtf8(""));
        infoLabel->setWordWrap(true);

        verticalLayout->addWidget(infoLabel);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_3);


        horizontalLayout_2->addLayout(verticalLayout);


        verticalLayout_3->addLayout(horizontalLayout_2);

        detailsTitleLabel = new QLabel(MainWidget);
        detailsTitleLabel->setObjectName("detailsTitleLabel");
        sizePolicy.setHeightForWidth(detailsTitleLabel->sizePolicy().hasHeightForWidth());
        detailsTitleLabel->setSizePolicy(sizePolicy);
        detailsTitleLabel->setText(QString::fromUtf8(""));
        detailsTitleLabel->setWordWrap(true);

        verticalLayout_3->addWidget(detailsTitleLabel);

        detailsLabel = new QLabel(MainWidget);
        detailsLabel->setObjectName("detailsLabel");
        sizePolicy.setHeightForWidth(detailsLabel->sizePolicy().hasHeightForWidth());
        detailsLabel->setSizePolicy(sizePolicy);
        detailsLabel->setText(QString::fromUtf8(""));
        detailsLabel->setWordWrap(true);
        detailsLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);

        verticalLayout_3->addWidget(detailsLabel);


        retranslateUi(MainWidget);

        QMetaObject::connectSlotsByName(MainWidget);
    } // setupUi

    void retranslateUi(QWidget *MainWidget)
    {
        (void)MainWidget;
    } // retranslateUi

};

namespace Ui {
    class MainWidget: public Ui_MainWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MAINDIALOG_H

