/****************************************************************************
** Meta object code from reading C++ file 'credentialstore.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../drkonqi-6.6.4/src/qmlextensions/credentialstore.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'credentialstore.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15CredentialStoreE_t {};
} // unnamed namespace

template <> constexpr inline auto CredentialStore::qt_create_metaobjectdata<qt_meta_tag_ZN15CredentialStoreE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CredentialStore",
        "urlChanged",
        "",
        "emailChanged",
        "passwordChanged",
        "windowChanged",
        "load",
        "store",
        "drop",
        "canStore",
        "url",
        "email",
        "password",
        "window",
        "QWindow*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'urlChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'emailChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'passwordChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'windowChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'load'
        QtMocHelpers::MethodData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'store'
        QtMocHelpers::MethodData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'drop'
        QtMocHelpers::MethodData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'canStore'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'url'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'email'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'password'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'window'
        QtMocHelpers::PropertyData<QWindow*>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CredentialStore, qt_meta_tag_ZN15CredentialStoreE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CredentialStore::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CredentialStoreE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CredentialStoreE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15CredentialStoreE_t>.metaTypes,
    nullptr
} };

void CredentialStore::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CredentialStore *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->urlChanged(); break;
        case 1: _t->emailChanged(); break;
        case 2: _t->passwordChanged(); break;
        case 3: _t->windowChanged(); break;
        case 4: _t->load(); break;
        case 5: _t->store(); break;
        case 6: _t->drop(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CredentialStore::*)()>(_a, &CredentialStore::urlChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CredentialStore::*)()>(_a, &CredentialStore::emailChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CredentialStore::*)()>(_a, &CredentialStore::passwordChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CredentialStore::*)()>(_a, &CredentialStore::windowChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWindow* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->m_canStore; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->m_url; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->m_email; break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->m_password; break;
        case 4: *reinterpret_cast<QWindow**>(_v) = _t->m_window; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1:
            if (QtMocHelpers::setProperty(_t->m_url, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->urlChanged();
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_email, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->emailChanged();
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_password, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->passwordChanged();
            break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_window, *reinterpret_cast<QWindow**>(_v)))
                Q_EMIT _t->windowChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *CredentialStore::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CredentialStore::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CredentialStoreE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int CredentialStore::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void CredentialStore::urlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void CredentialStore::emailChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void CredentialStore::passwordChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void CredentialStore::windowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
