/****************************************************************************
** Meta object code from reading C++ file 'Patient.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../drkonqi-6.6.4/src/coredump/gui/Patient.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Patient.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7PatientE_t {};
} // unnamed namespace

template <> constexpr inline auto Patient::qt_create_metaobjectdata<qt_meta_tag_ZN7PatientE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Patient",
        "changed",
        "",
        "launchDebugger",
        "reasonForNoDebug",
        "debug",
        "reasonForNoReport",
        "report",
        "signal",
        "appName",
        "pid",
        "pid_t",
        "timestamp",
        "time_t",
        "canDebug",
        "canReport",
        "dateTime",
        "iconName",
        "faultEntityName",
        "journalCursor"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'launchDebugger'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'reasonForNoDebug'
        QtMocHelpers::MethodData<QString() const>(4, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'debug'
        QtMocHelpers::MethodData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'reasonForNoReport'
        QtMocHelpers::MethodData<QString() const>(6, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'report'
        QtMocHelpers::MethodData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'signal'
        QtMocHelpers::PropertyData<int>(8, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'appName'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'pid'
        QtMocHelpers::PropertyData<pid_t>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 0),
        // property 'timestamp'
        QtMocHelpers::PropertyData<time_t>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 0),
        // property 'canDebug'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'canReport'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'dateTime'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'iconName'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'faultEntityName'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'journalCursor'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Patient, qt_meta_tag_ZN7PatientE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Patient::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7PatientE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7PatientE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7PatientE_t>.metaTypes,
    nullptr
} };

void Patient::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Patient *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changed(); break;
        case 1: _t->launchDebugger(); break;
        case 2: { QString _r = _t->reasonForNoDebug();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->debug(); break;
        case 4: { QString _r = _t->reasonForNoReport();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->report(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Patient::*)()>(_a, &Patient::changed, 0))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< pid_t >(); break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< time_t >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->m_signal; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->m_appName; break;
        case 2: *reinterpret_cast<pid_t*>(_v) = _t->m_pid; break;
        case 3: *reinterpret_cast<time_t*>(_v) = _t->m_timestamp; break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->canDebug(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->canReport(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->dateTime(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->iconName(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->faultEntityName(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->m_journalCursor; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->m_signal, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_appName, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_pid, *reinterpret_cast<pid_t*>(_v)))
                Q_EMIT _t->changed();
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_timestamp, *reinterpret_cast<time_t*>(_v)))
                Q_EMIT _t->changed();
            break;
        default: break;
        }
    }
}

const QMetaObject *Patient::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Patient::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7PatientE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Patient::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void Patient::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
